@@ -18,17 +18,17 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <qtest.h>
-
 #include "jobremotetest.h"
 
+#include <qtest.h>
+
 #include <QDebug>
 #include <klocalizedstring.h>
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QEventLoop>
-#include <QtCore/QDir>
-#include <QtCore/QVariant>
+#include <QFileInfo>
+#include <QEventLoop>
+#include <QDir>
+#include <QVariant>
 #include <QUrl>
 
 #include <kprotocolinfo.h>
@@ -83,7 +83,7 @@ static bool myMkdir(const QUrl &url)
 
 void JobRemoteTest::initTestCase()
 {
-    QStandardPaths::enableTestMode(true);
+    QStandardPaths::setTestModeEnabled(true);
 
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
